experimental_lowqa.tasks.yambs package — docs

Skip to main content
`Ctrl`+`K`

# experimental_lowqa.tasks.yambs package

## Subpackages

- experimental_lowqa.tasks.yambs.jlink package
  - Submodules
  - experimental_lowqa.tasks.yambs.jlink.gdbserver module
    - `jlink_gdbserver_task()`
  - Module contents
    - `JlinkExtract`
      - `JlinkExtract.run()`
    - `JlinkTask`
      - `JlinkTask.default_requirements`
      - `JlinkTask.run()`
    - `find_jlink_dir()`
    - `register_jlink()`

## Submodules

## experimental_lowqa.tasks.yambs.common module

Utilities common to multiple project tasks.

experimental_lowqa.tasks.yambs.common.add_path(path: Path) → None

  Add to the system path variable.

experimental_lowqa.tasks.yambs.common.add_program_path(program: str, third_party: Path, *parts: str, update_path: bool = False, local_bin: bool = False) → bool

  Register a path to a program.

experimental_lowqa.tasks.yambs.common.is_local_bin(program: str) → bool

  Determine if a binary or entry script is installed locally.

experimental_lowqa.tasks.yambs.common.lbin(program: str) → Path

  Get the path to a local binary.

experimental_lowqa.tasks.yambs.common.link_local_bin(path: Path) → None

  Link a local binary from some arbitrary location.

experimental_lowqa.tasks.yambs.common.program_str(program: str) → str

  Get a string path to a program.

## experimental_lowqa.tasks.yambs.gcov module

A module for working with gcov outputs.

experimental_lowqa.tasks.yambs.gcov.gcov_data(root: Path) → Iterator[Path]

  Find all gcov data files from a root directory.

experimental_lowqa.tasks.yambs.gcov.remove_gcov_data(root: Path) → None

  Remove all files ending in .gcda, starting from the provided directory.

## experimental_lowqa.tasks.yambs.udev module

A module for udev-rule tasks.

async experimental_lowqa.tasks.yambs.udev.install_udev_rule(task: SubprocessLogMixin, path: Path) → bool

  Install a udev rule.

## Module contents